==> coin2_2.4.6.orig.tar.gz: Coin-2.4.6/src/fields/all-fields-cpp.cpp <==
/**************************************************************************\
 *
 *  This file is part of the Coin 3D visualization library.
 *  Copyright (C) 1998-2007 by Systems in Motion.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  ("GPL") version 2 as published by the Free Software Foundation.
 *  See the file LICENSE.GPL at the root directory of this source
 *  distribution for additional information about the GNU GPL.
 *
 *  For using Coin with software that can not be combined with the GNU
 *  GPL, and for taking advantage of the additional benefits of our
 *  support services, please contact Systems in Motion about acquiring
 *  a Coin Professional Edition License.
 *
 *  See http://www.coin3d.org/ for more information.
 *
 *  Systems in Motion, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
 *  http://www.sim.no/  sales@sim.no  coin-support@coin3d.org
 *
\**************************************************************************/

#include "SoField.cpp"
#include "SoFieldContainer.cpp"
#include "SoFieldData.cpp"
#include "SoMFBitMask.cpp"
#include "SoMFBool.cpp"
#include "SoMFColor.cpp"
#include "SoMFEngine.cpp"
#include "SoMFEnum.cpp"
#include "SoMFFloat.cpp"
#include "SoMFInt32.cpp"
#include "SoMFMatrix.cpp"
#include "SoMFName.cpp"
#include "SoMFNode.cpp"
#include "SoMFPath.cpp"
#include "SoMFPlane.cpp"
#include "SoMFRotation.cpp"
#include "SoMFShort.cpp"
#include "SoMFString.cpp"
#include "SoMFTime.cpp"
#include "SoMFUInt32.cpp"
#include "SoMFUShort.cpp"
#include "SoMFVec2f.cpp"
#include "SoMFVec3f.cpp"
#include "SoMFVec3d.cpp"
#include "SoMFVec4f.cpp"
#include "SoMField.cpp"
#include "SoSFBitMask.cpp"
#include "SoSFBool.cpp"
#include "SoSFColor.cpp"
#include "SoSFEngine.cpp"
#include "SoSFEnum.cpp"
#include "SoSFFloat.cpp"
#include "SoSFImage.cpp"
#include "SoSFImage3.cpp"
#include "SoSFInt32.cpp"
#include "SoSFMatrix.cpp"
#include "SoSFName.cpp"
#include "SoSFNode.cpp"
#include "SoSFPath.cpp"
#include "SoSFPlane.cpp"
#include "SoSFRotation.cpp"
#include "SoSFShort.cpp"
#include "SoSFString.cpp"
#include "SoSFTime.cpp"
#include "SoSFTrigger.cpp"
#include "SoSFUInt32.cpp"
#include "SoSFUShort.cpp"
#include "SoSFVec2s.cpp"
#include "SoSFVec2f.cpp"
#include "SoSFVec3s.cpp"
#include "SoSFVec3f.cpp"
#include "SoSFVec3d.cpp"
#include "SoSFVec4f.cpp"
#include "SoSFBox3s.cpp"
#include "SoSFBox3f.cpp"
#include "SoSField.cpp"
#include "SoGlobalField.cpp"
#include "shared.cpp"

==> coin2_2.5.0.orig.tar.gz: Coin-2.5.0/src/fields/all-fields-cpp.cpp <==
/**************************************************************************\
 *
 *  This file is part of the Coin 3D visualization library.
 *  Copyright (C) 1998-2007 by Systems in Motion.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  ("GPL") version 2 as published by the Free Software Foundation.
 *  See the file LICENSE.GPL at the root directory of this source
 *  distribution for additional information about the GNU GPL.
 *
 *  For using Coin with software that can not be combined with the GNU
 *  GPL, and for taking advantage of the additional benefits of our
 *  support services, please contact Systems in Motion about acquiring
 *  a Coin Professional Edition License.
 *
 *  See http://www.coin3d.org/ for more information.
 *
 *  Systems in Motion, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
 *  http://www.sim.no/  sales@sim.no  coin-support@coin3d.org
 *
\**************************************************************************/

#include "SoField.cpp"
#include "SoFieldContainer.cpp"
#include "SoFieldData.cpp"
#include "SoMFBitMask.cpp"
#include "SoMFBool.cpp"
#include "SoMFColor.cpp"
#include "SoMFColorRGBA.cpp"
#include "SoMFDouble.cpp"
#include "SoMFEngine.cpp"
#include "SoMFEnum.cpp"
#include "SoMFFloat.cpp"
#include "SoMFInt32.cpp"
#include "SoMFMatrix.cpp"
#include "SoMFName.cpp"
#include "SoMFNode.cpp"
#include "SoMFPath.cpp"
#include "SoMFPlane.cpp"
#include "SoMFRotation.cpp"
#include "SoMFShort.cpp"
#include "SoMFString.cpp"
#include "SoMFTime.cpp"
#include "SoMFUInt32.cpp"
#include "SoMFUShort.cpp"
#include "SoMFVec2b.cpp"
#include "SoMFVec2s.cpp"
#include "SoMFVec2i32.cpp"
#include "SoMFVec2f.cpp"
#include "SoMFVec2d.cpp"
#include "SoMFVec3b.cpp"
#include "SoMFVec3s.cpp"
#include "SoMFVec3i32.cpp"
#include "SoMFVec3f.cpp"
#include "SoMFVec3d.cpp"
#include "SoMFVec4b.cpp"
#include "SoMFVec4s.cpp"
#include "SoMFVec4i32.cpp"
#include "SoMFVec4f.cpp"
#include "SoMFVec4d.cpp"
#include "SoMFVec4ub.cpp"
#include "SoMFVec4us.cpp"
#include "SoMFVec4ui32.cpp"
#include "SoMField.cpp"
#include "SoSFBitMask.cpp"
#include "SoSFBool.cpp"
#include "SoSFBox2s.cpp"
#include "SoSFBox2i32.cpp"
#include "SoSFBox2f.cpp"
#include "SoSFBox2d.cpp"
#include "SoSFBox3s.cpp"
#include "SoSFBox3i32.cpp"
#include "SoSFBox3f.cpp"
#include "SoSFBox3d.cpp"
#include "SoSFColor.cpp"
#include "SoSFColorRGBA.cpp"
#include "SoSFDouble.cpp"
#include "SoSFEngine.cpp"
#include "SoSFEnum.cpp"
#include "SoSFFloat.cpp"
#include "SoSFImage.cpp"
#include "SoSFImage3.cpp"
#include "SoSFInt32.cpp"
#include "SoSFMatrix.cpp"
#include "SoSFName.cpp"
#include "SoSFNode.cpp"
#include "SoSFPath.cpp"
#include "SoSFPlane.cpp"
#include "SoSFRotation.cpp"
#include "SoSFShort.cpp"
#include "SoSFString.cpp"
#include "SoSFTime.cpp"
#include "SoSFTrigger.cpp"
#include "SoSFUInt32.cpp"
#include "SoSFUShort.cpp"
#include "SoSFVec2b.cpp"
#include "SoSFVec2s.cpp"
#include "SoSFVec2i32.cpp"
#include "SoSFVec2f.cpp"
#include "SoSFVec2d.cpp"
#include "SoSFVec3b.cpp"
#include "SoSFVec3s.cpp"
#include "SoSFVec3i32.cpp"
#include "SoSFVec3f.cpp"
#include "SoSFVec3d.cpp"
#include "SoSFVec4b.cpp"
#include "SoSFVec4s.cpp"
#include "SoSFVec4i32.cpp"
#include "SoSFVec4f.cpp"
#include "SoSFVec4d.cpp"
#include "SoSFVec4ub.cpp"
#include "SoSFVec4us.cpp"
#include "SoSFVec4ui32.cpp"
#include "SoSField.cpp"
#include "SoGlobalField.cpp"
#include "shared.cpp"
